from django.shortcuts import render, redirect
from django.contrib.auth import login
from django.contrib.auth.models import User
from django.contrib.auth import logout
from django.views.decorators.csrf import csrf_exempt
from django.http import JsonResponse
import csv
import os

# Fichier CSV pour stocker les scores
CSV_FILE = "scores.csv"
DIFFICULTY_FILE = "difficulties.csv"


def init_csv():
    if not os.path.exists(CSV_FILE):
        with open(CSV_FILE, 'w', newline='') as file:
            writer = csv.writer(file)
            writer.writerow(["username", "score"])

def read_scores():
    scores = {}
    try:
        with open(CSV_FILE, 'r') as file:
            reader = csv.reader(file)
            next(reader)  # Ignorer l'en-tête
            for row in reader:
                scores[row[0]] = int(row[1])
    except FileNotFoundError:
        init_csv()
    return scores

def update_score(username, points):
    scores = read_scores()
    scores[username] = scores.get(username, 0) + points
    with open(CSV_FILE, 'w', newline='') as file:
        writer = csv.writer(file)
        writer.writerow(["username", "score"])
        for user, score in scores.items():
            writer.writerow([user, score])

def login_view(request):
    if request.method == "POST":
        username = request.POST["username"]
        user, created = User.objects.get_or_create(username=username)
        login(request, user)
        return redirect("challenges")
    return render(request, "login.html")

def challenges_view(request):
    if not request.user.is_authenticated:
        return redirect("login")
    challenges = ["Monter les escaliers", "1h de bureau debout", "Faire 5000 pas"]
    return render(request, "challenges.html", {"challenges": challenges})

def complete_challenge(request):
    if request.method == "POST":
        challenge_points = {
            "Monter les escaliers": 100,
            "1h de bureau debout": 50,
            "Faire 5000 pas": 200
        }
        challenge = request.POST.get("challenge")
        if challenge in challenge_points:
            update_score(request.user.username, challenge_points[challenge])
        return JsonResponse({"success": True})

def ranking_view(request):
    scores = read_scores()
    sorted_scores = sorted(scores.items(), key=lambda x: x[1], reverse=True)
    return render(request, "ranking.html", {"scores": sorted_scores})

def logout_view(request):
    logout(request)  # This logs out the user
    return redirect('login')

@csrf_exempt
def update_difficulty(request):
    if request.method == "POST":
        difficulty = request.POST.get("difficulty", "moyen")  # Valeur par défaut
        user = request.user.username if request.user.is_authenticated else "guest"  # Utilisateur authentifié ou invité

        scores = []
        user_found = False

        if os.path.exists(DIFFICULTY_FILE):
            with open(DIFFICULTY_FILE, "r", newline="", encoding="utf-8") as file:
                reader = csv.reader(file)
                for row in reader:
                    if len(row) < 2:
                        continue  # Ignorer les lignes mal formées, on s'attend à [username, difficulty]
                    
                    if row[0] == user:
                        row[1] = difficulty  # Modifier uniquement la difficulté (plus de score)
                        user_found = True
                    scores.append(row)

        if not user_found:
            scores.append([user, difficulty])  # Ajouter utilisateur avec difficulté choisie (sans score)

        with open(DIFFICULTY_FILE, "w", newline="", encoding="utf-8") as file:
            writer = csv.writer(file)
            writer.writerows(scores)

        return JsonResponse({"status": "success", "difficulty": difficulty})

    return JsonResponse({"status": "error", "message": "Invalid request"}, status=400)